@@ -871,6 +871,7 @@ system.get_time = function()
     if primary_instance and ARGS[2] then
       local open_directory = false
       for i=2, #ARGS do
+        -- chdir to initial working directory to properly resolve absolute path
         system.chdir(core.init_working_dir)
         local path = system.absolute_path(ARGS[i])
 
@@ -899,6 +900,10 @@ system.get_time = function()
       if not open_directory then
         os.exit()
       end
+      -- revert chdir to core.init_working_dir
+      if core.projects[1] then
+        system.chdir(core.projects[1].path)
+      end
     end
   else
     system.get_time = system_get_time
